#!/bin/bash

# Packager : Markus Muttilainen <stillborn.zenwalk@gmail.com>
# source location : http://arora.googlecode.com/files/arora-0.11.0.tar.gz
(

set -e -u -x

soft='arora'
softversion='0.11.0'
packageversion='70.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="/tmp/$package"
source="http://arora.googlecode.com/files/arora-0.11.0.tar.gz"

cd $buildir
rm -rf $src
rm -f $dest.txz
rm -rf $dest
mkdir -p $dest

#> check for sources
if [ -f $soft-$softversion.tar.gz ]; then
        echo "Source file already here, no need to download";
else
        echo "Downloading source"
        wget -c --no-check-certificate $source
fi

tar -xvf $srcpkg
cd $src

#> fix permissions and ownership
        chown -R root:root .
        find . -perm 777 -exec chmod 755 {} \;
        find . -perm 775 -exec chmod 755 {} \;
        find . -perm 666 -exec chmod 644 {} \;
        find . -perm 664 -exec chmod 644 {} \;
        find . -perm 600 -exec chmod 644 {} \;
        find . -perm 444 -exec chmod 644 {} \;
        find . -perm 400 -exec chmod 644 {} \;
        find . -perm 440 -exec chmod 644 {} \;
        find . -perm 511 -exec chmod 755 {} \;
        find . -perm 711 -exec chmod 755 {} \;
        find . -perm 555 -exec chmod 755 {} \;

#> /usr/lib/qt/mkspecs/common/g++.conf
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

qmake $soft.pro PREFIX=/usr
( cd src
  qmake src.pro -unix PREFIX=/usr -o Makefile
#  sed -i s%i486%i686%g Makefile
  sed -i s%qrc:/startpage.html%http://www.zenwalk.org% tabwidget.cpp
  sed -i s%startpage.html%www.zenwalk.org% webpage.cpp
  sed -i s%StartupNotify=true%StartupNotify=false% $soft.desktop
)
make -j3
make INSTALL_ROOT=$dest install

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
                xargs -r strip --strip-unneeded 2> /dev/null || true
        find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
                xargs -r strip --strip-unneeded 2> /dev/null || true
)
mv $dest/usr/share/man $dest/usr/man
( cd $dest/usr/man
  find . -type f -name "*.?" -exec gzip -9 {} \;
  for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
)

mkdir -p $dest/usr/{src,doc}/$soft-$softversion
( cd $src 
cp -av \
  AUTHORS ChangeLog LICENSE.GPL2 LICENSE.GPL3 README \
  $dest/usr/doc/$soft-$softversion
cd $buildir
cp -v build-$soft.sh $dest/usr/src/$soft-$softversion/
)  

mkdir -p $dest/install
    #|-----handy-ruler-------------------------------------------------------|
cat << "EOF" > $dest/install/slack-desc
arora: arora - (simple cross platform web browser.)
arora: 
arora: Arora is a simple cross platform web browser whose feature list
arora: includes things like "History" and "Bookmarks". Benjamin Meyer 
arora: originally created as a demo for Qt to help test the QtWebKit component
arora: and find API issues and bugs before the release. Arora works on Linux,
arora: OS X, Windows, FreeBSD, and embedded Linux using Qt Embedded and
arora: anywhere Qt does. For more information about the project check out the
arora: Arora Goals wiki page.
arora: 
arora: http://code.google.com/p/arora/
EOF

cat << "EOF" > $dest/install/doinst.sh
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi 
EOF

mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
cp -v $buildir/$soft.png $dest/usr/share/icons/hicolor/48x48/apps
#( cd src/data
#  inkscape -z -w48 -h48 --export-png=$dest/usr/share/icons/hicolor/48x48/apps/$soft.png $soft.svg
#)

#> redundant
rm -rfv $dest/usr/share/doc

#> helperline
(cd $dest;find . -printf "%y %m %u:%g %p %l\n") >$buildir/pkgtree.log

cd $dest
/sbin/makepkg -l y -c n $dest.txz

echo 'Calculating MD5 checksum...'
/bin/md5sum $dest.txz > $dest.md5
mv -v $dest.* $buildir

) 2>&1 | tee build-arora.log.txt

#> cleanup
rm -rf $dest
rm -rf $src
